# This script imports DLS data from *.txt files exported by Malverns Zetasizer software.
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223
library(tidyverse)
library(stringr)

#import data
size_ca <- as.tibble(read.delim("size_core_in_acetone.txt", header = TRUE, dec=","))
size_csa <- as.tibble(read.delim("size_core+shell_in_acetone.txt", header = TRUE, dec=","))
size_cs <- as.tibble(read.delim("size_core+shell.txt", header = TRUE, dec=",")) # Core and Shell (lipid anchor) premixed, afterwards siRNA was added. Core: 992 Shell: 1203, 1223
size_cs_4inlet <- as.tibble(read.delim("size_core+shell_4inlet_2meander.txt", header = TRUE, dec=",")) # everything mixed in one channel: c1: 992, c2: siRNA, -meander- c3, c4: shell (1203 or 1223) -meander-
size_csa_4inlet <- as.tibble(read.delim("size_core+shell_4inlet_2meander_20190129.txt", header = TRUE, dec=",")) # everything mixed in one channel: c1: 991, c2: siRNA, -meander- c3, c4: shell (1203 or 1223) -meander-
zeta_csa_4inlet <- as.tibble(read.delim("zeta_core+shell_4inlet_2meander_20190129.txt", header = TRUE, dec=",")) # everything mixed in one channel: c1: 991, c2: siRNA, -meander- c3, c4: shell (1203 or 1223) -meander-
size_cs_ratios <- as.tibble(read.delim("size_core+shell_mixing_ratios.txt", header = TRUE, dec=",")) # core mixed in a 2-inlet channel: c1: 992, c2: siRNA, different flowrate ratios used
size_tj1 <- as.tibble(read.delim("size_tjunction.txt", header = TRUE, dec=","))%>%
  mutate(id = 1)
size_tj2 <- as.tibble(read.delim("size_tjunction_2.txt", header = TRUE, dec=","))%>%
  mutate(id = 2)

size_tj <- rbind(size_tj1, size_tj2) 
# extract information from "Sample.name" and create new colums from it
size_cs <- size_cs %>%
  mutate(shell = if_else(str_detect(Sample.Name, "1223"), 1223, 1203)) %>%
  mutate("mol%" = str_extract(Sample.Name, "\\d\\dmol%")) %>%
  mutate(`mol%` = str_extract(`mol%`, "\\d\\d")) %>%
  mutate( id = "cs")

size_cs_4inlet_tidy <- size_cs_4inlet %>%
  mutate(shell = if_else(str_detect(Sample.Name, "1223"), 1223, 1203)) %>%
  mutate("mol%" = str_extract(Sample.Name, "\\d{1,2}\\??mol%")) %>%
  mutate(`mol%` = str_extract(`mol%`, "\\d{1,2}"))%>%
  mutate( id = "cs_4inlet")

size_csa_4inlet <- size_csa_4inlet %>%
  filter(!is.na(PdI)) %>%
  mutate(shell = if_else(str_detect(Sample.Name, "1223"), "SPE", "none")) %>%
  mutate(shell = if_else(str_detect(Sample.Name, "1203"), "SP", shell)) %>%
  mutate("mol%" = 20) %>%
  mutate("NP" = 12) %>%
  mutate( id = "csa_4inlet") %>%
  mutate(acetone = if_else(str_detect(Sample.Name, "Ac"), "+", "-")) %>%
  mutate(ligand = if_else(str_detect(Sample.Name, "DP12F"), "DP12F", "none")) %>%
  mutate(ligand = if_else(str_detect(Sample.Name, "DP24F"), "DP24F", ligand)) %>%
  mutate(formulation = if_else(str_detect(shell, "none"), "core", "core-SP")) %>%
  mutate(formulation = if_else(str_detect(shell, "SPE"), "core-SPE", formulation)) %>%
  mutate(formulation = if_else(ligand == "DP12F", "core-SPE-\nDP12F", formulation)) %>%
  mutate(formulation = if_else(ligand == "DP24F", "core-SP-\nDP24F", formulation)) %>%
  mutate(prod_method = if_else(str_detect(Sample.Name, "Micro"), "micro", "hand"))
  
 
size_cs_ratios <- size_cs_ratios %>%
  mutate(shell = "none")%>%
  mutate(`mol%` = "0")%>%
  mutate( id = "cs_ratios")

size_csa <- size_csa %>% 
  mutate(shell = if_else(str_detect(Sample.Name, "1223"), 1223, 1203)) %>% # column "shell" must be added before rbind is called because of errors in naming the sample
  mutate(`mol%` = 20)%>%
  mutate( id = "csa")

size_ca <- size_ca %>%
  mutate(shell = "none") %>%
  mutate(`mol%` = 0)%>%
  mutate( id = "ca")

size <- rbind(size_ca, size_csa, size_cs, size_cs_4inlet_tidy, size_cs_ratios)


size_NP_FR_shell <- size %>%
  mutate(NP = if_else((str_detect(Sample.Name, "NP\\d+")),str_extract(Sample.Name, "NP\\d+"), "12")) %>%
  mutate(NP = as.double(str_extract(NP, "\\d+"))) %>%
  mutate(FR = if_else(str_detect(Sample.Name, "FRR 1/10"), "1/10", "none")) %>%
  mutate(FR = if_else(NP == 3, "1/20", FR)) %>%
  mutate(FR = if_else(NP == 6, "1/11", FR)) %>%
  mutate(FR = if_else(NP == 9, "1/7", FR)) %>%
  mutate(FR = if_else(str_detect(id, "ca") & str_detect(FR, "none") , "1/6", FR)) %>%
  mutate(formulation = if_else(shell == "none", "core", "core shell (1203)")) %>%
  mutate(formulation = if_else(shell == "1223", "core shell (1223)", formulation)) %>%
  mutate(formulation = if_else(`mol%` == 0, "core", formulation)) %>%
  mutate(shell = if_else(`mol%` == 0, "none", shell)) %>%
  mutate(acetone = if_else(FR == "none", "-", "+"))

# extract information for t junction data
add_FR <- size_tj %>%
  mutate(FR = str_extract(Sample.Name, "\\d+,?\\d?[ ]+ml/h"))

add_FR_2 <- add_FR %>%
  filter(is.na(FR))%>%
  mutate(FR = str_extract(Sample.Name, "\\d+k"))

add_FR_3 <-   add_FR_2 %>%
  filter(is.na(FR)) %>%
  filter(Sample.Name == str_extract(Sample.Name, "^9.*siRNA[ ]\\d$"))%>%
  mutate(FR = "hand")

comb_FR <- rbind (add_FR, add_FR_2, add_FR_3) %>%
  filter(!is.na(FR) )%>%
  filter(!is.na(PdI))

# add coding variables to tjunction data: flow rate (FR) und acetone concentration (acetone)
comb_FR <- comb_FR %>%
  mutate(FR = str_extract(FR, "(\\d,\\d|\\d+)|(\\D{3,})")) %>% 
  mutate(acetone = str_extract(Sample.Name, "(\\d,\\d|\\d+)[ ]?%")) %>%
  replace_na(list(acetone = "0%"))

comb_FR_subset <- comb_FR %>%
  filter(str_detect(comb_FR$Sample.Name, "tjunction")) %>%
  mutate(FR = as.double(str_extract(FR, "\\d+"))/2)

comb_FR <- comb_FR %>%
  filter(!str_detect(comb_FR$Sample.Name, "tjunction"))

DLS_ZAv_tj <- rbind(comb_FR,comb_FR_subset)%>%
  select (Sample.Name,id, FR, acetone, Z.Average..d.nm., PdI)%>%
  mutate ( NP = 12 ) %>% 
  mutate (formulation = "core") %>%
  mutate (shell = "none") %>%
  mutate (`mol%` = "0" ) 


# transform for z-average plot
size_tidy <- size_NP_FR_shell %>%
  select(Sample.Name, Z.Average..d.nm., PdI, NP, FR,formulation, shell, `mol%`, id, acetone) %>%
  filter (!is.na(PdI)) 

size_zAv_plot_micro <- size_tidy %>%
  filter(NP == 12) %>%
  filter(FR != "1/6") %>%
  filter (`mol%` == "0" | `mol%` == "20") %>%
  filter (id != "cs_ratios") %>%
  filter( id != "cs_4inlet" | formulation != "core shell (1203)") %>%
  filter( id != "cs_4inlet" | formulation != "core shell (1223)") %>%
  filter (shell == "none")

size_zAv_plot_tj <- DLS_ZAv_tj %>%
  filter(FR == "30" | FR == "hand") %>%
  filter (acetone != "0%" | Z.Average..d.nm. <123 ) %>% # remove faulty measurement
  filter (acetone != "2,5%")

size_zAv_plot <- rbind (size_zAv_plot_tj, size_zAv_plot_micro) %>%
  mutate (name = ifelse(FR == "hand", "hand", "micro")) %>%
  mutate (name = ifelse(FR == "30", "t-junc.", name)) %>%
  mutate(acetone_simple = ifelse(acetone == "0%", "-", "+")) %>%
  mutate(acetone_simple = ifelse(acetone == "25%", "+", acetone_simple)) %>%
  mutate(acetone_simple = ifelse(acetone == "-", "-", acetone_simple))

size_zAv_plot$name <- factor(size_zAv_plot$name, levels = c("hand", "t-junc.", "micro"))  #change order of variable "names"

#define colours for plots
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey. From colour brewer

# plots
p2A <-  ggplot(size_zAv_plot, aes(name, Z.Average..d.nm., fill = acetone_simple, shape = acetone_simple)) +
  stat_summary(fun.y = mean, geom = "point", size = 3, position = position_dodge(width = 0.9)) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position = position_dodge(width = 0.9) ) + # confidence interval from 3 consecutive measurements
  labs(
    x = NULL,
    y = expression("d"[Z]*" [nm]"),
    title = "Core production methods",
    subtitle = expression("Mean hydrodynamic diameter d"[Z]),
    colour = NULL,
    fill = NULL,
    tag = "A"
  ) +
  theme_bw(
  ) +
  scale_y_continuous (
    limits = c(0,160)
  )+
  scale_fill_manual(
    values = c(colours [5], colours[2]), 
    name = "acetone"
  ) + 
  scale_shape_manual(
    values = c(21,22), 
    name = "acetone"
  ) + 
  theme(
    legend.position = c(0.5, 0.11),
    legend.direction = "horizontal", 
    legend.key = element_rect(color = "grey50"),
    legend.text = element_text(size = 15),
    legend.background = element_rect(size = 0.5, colour = "grey50")
    )

p2B <-  ggplot(size_zAv_plot, aes(name, PdI,  fill = acetone_simple, shape = acetone_simple)) + 
  stat_summary(fun.y = mean, geom = "point", size = 3, position = position_dodge(width = 0.9)) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position = position_dodge(width = 0.9) ) + # confidence interval from 3 consecutive measurements
  labs(
    x = "method",
    y = "PDI",
    subtitle = "Mean polydispersity index (PDI)",
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  theme_bw(
  ) +
  scale_y_continuous (
    limits = c(0,1)
  ) +
  scale_fill_manual(
    values = c(colours [5], colours[2]), 
    name = "acetone"
  ) + 
  scale_shape_manual(
    values = c(21,22), 
    name = "acetone"
  ) + 
  theme(
    legend.position = "none"
    )


# call multiplot to combine plots into one figure. copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

# save plots as .png
ggsave("Figure2.png", plot = multiplot(p2A, p2B, cols=1),  width = 9, height = 16, units = c("cm"), dpi = 300)

