# stats - takes variables from "Fig7_luc.R"
# this script calculates ANOVA, student's t-tests and cohen's d

library(car)
library(sjstats)
library(tidyverse)
library(effsize)

# filter data for Anova
Luc_tidy_GFP_aov <- Luc_tidy %>%
  filter(group == "GFP") %>%
  filter(id != "core\npolyplex") # since "core" is missing the ligands, calculating an anova with it produces an error -> remove

Luc_tidy_ctrl_aov <- Luc_tidy %>%
  filter(group == "ctrl") %>%
  filter(id != "core\npolyplex")

# filter data for post-hoc tests
Luc_tidy_GFP_ttest<- Luc_tidy %>%
  filter(group == "GFP") %>%
  mutate(name = str_c(id, `%`))

Luc_tidy_ctrl_ttest<- Luc_tidy %>%
  filter(group == "ctrl") %>%
  mutate(name = str_c(id, `%`))

# Anova for siGFP containing samples 
LucAssay_RLU_Model_GFP <-aov(rel_RLU ~ `%`*id, data = Luc_tidy_GFP_aov)
anova_GFP <- Anova(LucAssay_RLU_Model_GFP, type="III") # type: Displays type 1, 2 oder 3 sums of squares
anova_GFP$`Pr(>F)` # access anova results (stored as matrix)
summary.lm(LucAssay_RLU_Model_GFP) # alternative way to summarize the anova
anova_stats(LucAssay_RLU_Model_GFP) # displays stats associated with ANOVA (df sumsq meansq statistic p.value etasq partial.etasq omegasq partial.omegasq cohens.f power)
aov_GFP_omegasq <- anova_stats(LucAssay_RLU_Model_GFP)$omegasq

# Anova for sictrl containing samples 
LucAssay_RLU_Model_ctrl<-aov(rel_RLU ~ `%`*id, data = Luc_tidy_ctrl_aov)
anova_Ctrl <- Anova(LucAssay_RLU_Model_ctrl, type="III")
anova_Ctrl$`Pr(>F)`
summary.lm(LucAssay_RLU_Model_ctrl)
anova_stats(LucAssay_RLU_Model_ctrl) # displays stats associated with ANOVA (df sumsq meansq statistic p.value etasq partial.etasq omegasq partial.omegasq cohens.f power)
aov_ctrl_omegasq <- anova_stats(LucAssay_RLU_Model_ctrl)$omegasq


# Post Hoc Analysis (CAVE: when interactions are significant, post hoc tests on the main result are missleading)
ttest_GFP <- pairwise.t.test(Luc_tidy_GFP_ttest$rel_RLU, Luc_tidy_GFP_ttest$name, p.adjust.method = "none")  #bonferroni oder holm correction 

values_GFP<-as.tibble(ttest_GFP$p.value[1:20,1]) %>% # access p values by their position in a matrix
  rename(p_value = value)

sample_GFP<-as.tibble(names(ttest_GFP$p.value[1:20,1])) %>%
  rename(sample = value)

postHoc_GFP_uncorrected <- cbind(values_GFP, sample_GFP)

ttest_ctrl <- pairwise.t.test(Luc_tidy_ctrl_ttest$rel_RLU, Luc_tidy_ctrl_ttest$name, p.adjust.method = "none")
values<-as.tibble(ttest_ctrl$p.value[1:20,1]) %>% # access p values by their position in a matrix
  rename(p_value = value)

sample<-as.tibble(names(ttest_ctrl$p.value[1:20,1])) %>%
  rename(sample = value)

postHoc_ctrl_uncorrected <- cbind(values, sample)

# p value correction (HOLM)
postHoc_GFP_corrected <- postHoc_GFP_uncorrected %>%
  mutate(p.adjusted = p.adjust( postHoc_GFP_uncorrected$p_value, method = "holm")) %>%
  arrange (-desc(p.adjusted))%>%
  mutate(p.adjusted_rnd = round(p.adjusted, 3)) %>%
  mutate( ligand = str_extract(sample, "P?\\d*F")) %>%
  mutate( `%` = str_extract(sample, "\\d+$"))%>%
  mutate(`%` = as.double(`%`)) %>%
  mutate(ligand = factor(ligand, levels = id_all[3:7]))

postHoc_ctrl_corrected <- postHoc_ctrl_uncorrected %>%
  mutate(p.adjusted = p.adjust( postHoc_ctrl_uncorrected$p_value, method = "holm")) %>%
  arrange (-desc(p.adjusted))%>%
  mutate(p.adjusted_rnd = round(p.adjusted, 3))%>%
  mutate( ligand = str_extract(sample, "P?\\d*F")) %>%
  mutate( `%` = str_extract(sample, "\\d+$")) %>%
  mutate(`%` = as.double(`%`))%>%
  mutate(ligand = factor(ligand, levels = id_all[3:7]))

# filter significant values
p_adjusted_sig_GFP <- postHoc_GFP_corrected %>% # only values with p.adjusted. <= 0.05
  filter(p.adjusted <= 0.05)

p_adjusted_sig_ctrl <- postHoc_GFP_corrected %>% # only values with p.adjusted. <= 0.05
  filter(p.adjusted <= 0.05)

t_values_GFP <- postHoc_GFP_corrected %>%
  arrange (-desc(ligand)) %>%
  arrange (-desc(`%`)) %>%
  mutate(p_rnd = round(p_value, 3))%>%
  dplyr::select(`%`, ligand , p_rnd, p.adjusted_rnd)

t_values_ctrl <- postHoc_ctrl_corrected %>%
  arrange (-desc(ligand)) %>%
  arrange (-desc(`%`)) %>%
  mutate(p_rnd = round(p_value, 3))%>%
  dplyr::select(`%`, ligand , p_rnd, p.adjusted_rnd)

# calculate cohen's d
# GFP
#specify control values, select rel_RLU only.
control_GFP <- Luc_tidy_GFP_ttest %>%
  filter(name == "core\npolyplex0") %>%
  dplyr::select(rel_RLU)%>%
  mutate(rel_RLU = as.numeric(rel_RLU))

# convert name to factor to be able to use levels for selecting target values
Luc_tidy_GFP_ttest <- Luc_tidy_GFP_ttest %>%
  mutate(name = factor(name))

#creat a vector for adding results
cohens_GFP <- c() 

#iterate over all levels of the factor, calculate respective cohen's d and write to vector
for (i in levels(Luc_tidy_GFP_ttest$name)) {
  a <- Luc_tidy_GFP_ttest %>%
  filter(name == i) %>%
    dplyr::select(rel_RLU)
  b <- cohen.d(pull(a), pull(control_GFP))
  cohens_GFP <- c(cohens_GFP, b$estimate)
}

#combine add cohen's d to tibble with t values
cohens_GFP <- as.tibble(cbind( "name" = levels(Luc_tidy_GFP_ttest$name),"cohens_d" = cohens_GFP)) %>%
  mutate(cohens_d = as.double(cohens_d))

#create column "name" for joining two data frames
t_values_GFP <- t_values_GFP %>%
  mutate(name = str_c(ligand, `%`))
t_values_cohen_GFP <- left_join (t_values_GFP, cohens_GFP)

#ctrl
Luc_tidy_ctrl_ttest <- Luc_tidy_ctrl_ttest %>%
  mutate(name = factor(name))

control_ctrl <- Luc_tidy_ctrl_ttest %>%
  filter(name == "core\npolyplex0") %>%
  dplyr::select(rel_RLU)%>%
  mutate(rel_RLU = as.numeric(rel_RLU))

cohens_ctrl <- c() 

for (i in levels(Luc_tidy_ctrl_ttest$name)) {
  a <- Luc_tidy_ctrl_ttest %>%
    filter(name == i) %>%
    dplyr::select(rel_RLU)
  b <- cohen.d(pull(a), pull(control_ctrl))
  cohens_ctrl <- c(cohens_ctrl, b$estimate)
}

cohens_ctrl <- as.tibble(cbind( "name" = levels(Luc_tidy_ctrl_ttest$name),"cohens_d" = cohens_ctrl)) %>%
  mutate(cohens_d = as.double(cohens_d))
t_values_ctrl <- t_values_ctrl %>%
  mutate(name = str_c(ligand, `%`))
t_values_cohen_ctrl <- left_join (t_values_ctrl, cohens_ctrl)
