# This script imports DLS data from *.txt files exported by Malverns Zetasizer software.
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223

library(splitstackshape)
library(tidyverse)
library(RColorBrewer)

setwd() # choose the folder where the raw data is stored

# import data
DLS_991 <- as.tibble(read.delim("20181105_DLS.txt", header = TRUE, dec=","))
DLS_991_zeta <- as.tibble(read.delim("20181105_DLS_991_zeta.txt", header = TRUE, dec=","))

# select bins for violin plot
bins <- DLS_991 %>%
  select(Sample.Name, Sizes.1...d.nm.:Sizes.70...d.nm.)%>%
  gather(Sizes.1...d.nm.:Sizes.70...d.nm., key = "sizes", value = "bins")%>%
  filter(!is.na(bins))

# select intensities to the corresponding bins in "bins"
DLS_intensities <- DLS_991 %>%
  select(Sample.Name, Intensities.1...Percent.:Intensities.70...Percent.)%>%
  gather(Intensities.1...Percent.:Intensities.70...Percent., key = "intensity_bins", value = "intensities") %>%
  filter(!is.na(intensities))

# select z-average data
DLS_ZAv <- DLS_991 %>%
  select (Sample.Name, Z.Average..d.nm., PdI, PdI.Width..d.nm., Attenuator) %>%
  filter(!is.na(PdI))

#specify names
core_id <- "991"
core_name <- "CO"
shell_id <- c("1203", "1223")
shell_name <- c("LA", "LAE")
ligand_all <- c("DF", "DP3F", "DP12F", "DP24F", "DP48F")

# specify id for plotting the data (sample names on x axis). Changing oder of items in vector changes order on x-axis
id_all <- c("core\npolyplex", "P12", "P12F", "P15F", "P24F", "P36F", "P60F") # names depicted on x-axis
facet_all <- c("core", "core - LA", "core - LAE") # names for facettes

#tidy intensity data for violin plots
DLS_tidy <- DLS_intensities %>%
  mutate(core = str_extract(Sample.Name, str_c("(", str_c(core_id, collapse = ")|(") , ")")))%>%     # adds a new column according to string specified in variable "core"
  mutate(shell = str_extract(Sample.Name, str_c("(", str_c(shell_id, collapse = ")|(") , ")")))%>%   # adds a new column that specifies id of the used shell according to string specified in variable "shell"
  mutate(PEG_ligand = str_extract(Sample.Name, "D.*F")) %>%  # adds a new column that specifies names of the used PEG_ligand with regex that starts with D and stops with F
  replace_na(list(shell = 0, PEG_ligand = 0)) %>%
  mutate(core_name = ifelse(core == core_id, core_name, core))%>%
  mutate(shell_name = ifelse(shell == shell_id[1], facet_all[2], facet_all[1]))%>%
  mutate(shell_name = ifelse(shell == shell_id[2], facet_all[3], shell_name)) %>%
  mutate(shell_name = factor(shell_name, levels=facet_all)) %>%
  mutate(id = ifelse(shell_name == "core", id_all[1], id_all[2])) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[1], id_all[3], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[2], id_all[4], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[3], id_all[5], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[4], id_all[6], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[5], id_all[7], id)) %>%
  mutate(id = factor(id, levels=id_all))

#tidy z-average data
DLS_tidy_ZAv <- DLS_ZAv %>%
  mutate(core = str_extract(Sample.Name, str_c("(", str_c(core_id, collapse = ")|(") , ")")))%>%     # adds a mew column according to string specified in variable "core"
  mutate(shell = str_extract(Sample.Name, str_c("(", str_c(shell_id, collapse = ")|(") , ")")))%>%   # adds a new column that specifies id of the used shell according to string specified in variable "shell"
  mutate(PEG_ligand = str_extract(Sample.Name, "D.*F")) %>%  # adds a new column that specifies names of the used PEG_ligand with regex that starts with D and stops with F
  replace_na(list(shell = 0, PEG_ligand = 0)) %>%
  mutate(core_name = ifelse(core == core_id, core_name, core))%>%
  mutate(shell_name = ifelse(shell == shell_id[1], facet_all[2], facet_all[1]))%>%
  mutate(shell_name = ifelse(shell == shell_id[2], facet_all[3], shell_name)) %>%
  mutate(shell_name = factor(shell_name, levels=facet_all)) %>%
  mutate(id = ifelse(shell_name == "core", id_all[1], id_all[2])) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[1], id_all[3], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[2], id_all[4], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[3], id_all[5], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[4], id_all[6], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[5], id_all[7], id)) %>%
  mutate(id = factor(id, levels=id_all))

#tidy zeta potential data
DLS_tidy_zeta <- DLS_991_zeta %>%
  mutate(core = str_extract(Sample.Name, str_c("(", str_c(core_id, collapse = ")|(") , ")")))%>%     # adds a mew column according to string specified in variable "core"
  mutate(shell = str_extract(Sample.Name, str_c("(", str_c(shell_id, collapse = ")|(") , ")")))%>%   # adds a new column that specifies id of the used shell according to string specified in variable "shell"
  mutate(PEG_ligand = str_extract(Sample.Name, "D.*F")) %>%
  filter (!is.na(Zeta.Potential..mV.)) %>%
  select(sample = Sample.Name, zeta = Zeta.Potential..mV., zeta_dev = Zeta.Deviation..mV., current = Measured.Current..mA., cond = Conductivity..mS.cm., core:PEG_ligand ) %>%
  replace_na(list(shell = 0, PEG_ligand = 0)) %>% 
  mutate(lower = zeta - zeta_dev) %>%
  mutate(higher = zeta + zeta_dev)%>%
  mutate(core_name = ifelse(core == core_id, core_name, core))%>%
  mutate(shell_name = ifelse(shell == shell_id[1], facet_all[2], facet_all[1]))%>%
  mutate(shell_name = ifelse(shell == shell_id[2], facet_all[3], shell_name)) %>%
  mutate(shell_name = factor(shell_name, levels=facet_all)) %>%
  mutate(id = ifelse(shell_name == "core", id_all[1], id_all[2])) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[1], id_all[3], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[2], id_all[4], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[3], id_all[5], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[4], id_all[6], id)) %>%
  mutate(id = ifelse(PEG_ligand == ligand_all[5], id_all[7], id)) %>%
  mutate(id = factor(id, levels=id_all))

#define bins
DLS_tidy$bins <- bins$bins

# calculate errorbars zeta potential
DLS_tidy_zeta_errorbars<- DLS_tidy_zeta %>%
  group_by(shell_name, id) %>%
  summarise(mean_lower = mean(lower), mean_higher = mean(higher))

#transform data for violin plot
violin_data <- DLS_tidy %>%
  group_by(bins, shell_name, id) %>%
  summarise(sum_intensities = sum(intensities)*10 )

# multiply rows by the value in "sum_intensities"
violin_data2 <- expandRows(violin_data, "sum_intensities") 

#ZAv Data
ZAv_Data <- DLS_tidy_ZAv %>%
  group_by(shell_name, id) %>%
  summarise(
    ZAv_mean = mean(Z.Average..d.nm., na.rm = TRUE),
    ZAv_sd = sd(Z.Average..d.nm., na.rm = TRUE)
  ) %>%
  mutate(ymin = ZAv_mean - ZAv_sd) %>%
  mutate(ymax = ZAv_mean + ZAv_sd)

#PDI Data
pdi_Data <- DLS_tidy_ZAv %>%
  group_by(shell_name, id) %>%
  summarise(
    pdi_mean = mean(PdI, na.rm = TRUE),
    pdi_sd = sd(PdI, na.rm = TRUE)
  ) %>%
  mutate(ymin = pdi_mean - pdi_sd) %>%
  mutate(ymax = pdi_mean + pdi_sd)

#define colours
colours <- brewer.pal(8, "Paired")
colours_core <- c(rep(colours[1], 5), rep(colours[2], 5))

# Plots - z-average, violine plot
p3A <- ggplot (violin_data2, aes(x = id, y = bins)) +
  geom_violin(aes(colour = shell_name)) + 
  geom_point(data = ZAv_Data, aes(id, ZAv_mean, fill = "z-average"), colour = "red", size = 3) +
  coord_trans(y='log10') + 
  scale_y_continuous (
    minor_breaks = c(c(1:9), seq(10, 90, 10), seq(100, 900, 100), seq(1000, 10000, 1000) ),
    limits = c(1, 10000), 
    breaks = c(1, 10, 100, 300, 1000, 10000)
    ) + 
  facet_grid(~ shell_name, 
             scales = "free_x", 
             space = "free_x"
  ) +
  geom_errorbar(
    data = ZAv_Data, 
    aes(x = ZAv_Data$id, 
        ymin = ymin, 
        ymax = ymax), 
    width = 0.4, 
    inherit.aes = FALSE 
    ) + 
  labs(
    x = NULL, 
    y = expression("d"[H]*" [nm]"),
    title = "DLS data of core - lipid anchor - PEG-ligand polyplexes",
    subtitle = expression("Hydrodynamic diameter d"[H]),
    colour = NULL,
    tag = "A"
  ) +
  theme_bw() +
  theme(legend.position = c(1, 0), 
        legend.justification = c(1, 0),
        legend.title = element_blank(),
        legend.background = element_rect(size = 0.5, colour = "grey50")
        ) +
  scale_colour_manual(
    values = c(colours [4], colours[2], colours[8]),
    guide = FALSE
    ) 

#Plot: Zeta potential
p3C <- ggplot(DLS_tidy_zeta, aes(id, zeta, fill = shell_name)) +
  stat_summary(fun.y = mean, geom = "bar") + 
  geom_errorbar(data=DLS_tidy_zeta_errorbars,  aes(y=NULL, x= id, ymin = mean_lower, ymax = mean_higher),   width=.2, position=position_dodge(0.9) )+ # +- zeta deviation
  labs(
    x = "formulation",
    y = "zeta potential [mV]",
    subtitle = "Zeta potential",
    colour = NULL,
    fill = NULL,
    tag = "C"
  ) +
  theme_bw(
  ) +
  theme(legend.position = "none") +
  facet_grid(~ shell_name, 
             scales = "free_x", 
             space = "free_x"
  ) +
  scale_fill_manual(
    values = c(colours [4], colours[2], colours[8])
  )

#Plot - PDI
p3B <-  ggplot(pdi_Data, aes(id, pdi_mean, colour = shell_name)) +
  stat_summary(fun.y = mean, geom = "point", size = 3) + 
  geom_errorbar(aes(y=NULL, x= id, ymin = ymin, ymax = ymax),   width=.2, colour = "black" )+ # +- pdi standard deviation
  labs(
    x = NULL,
    y = "pdi",
    subtitle = "Polydispersity index (pdi)",
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  theme_bw(
  ) +
  theme(legend.position = "none"
  ) +
  facet_grid(~ shell_name, 
             scales = "free_x", 
             space = "free_x"
  ) +
  scale_colour_manual(
    values = c(colours [4], colours[2], colours[8])
  )
# call multiplot to combine plots into one figure. copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

# save plots as .png
ggsave("Figure3.png", plot = multiplot(p3A, p3B, p3C,  cols=1),  width = 16, height = 27, units = c("cm"), dpi = 300)

