# This script imports data from *.xlsx files exported by Centro LB 960 luminometer (BertholdTech CENTRO, Driver V. 1.21, MikroWin, V. 5.2)
# and calculates ANOVA, student's t-tests and cohen's d. 
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223

library(tidyverse)
library(readxl)
library(RColorBrewer)
library(ggsignif)

setwd() # choose the folder where the raw data is stored

#specify sample names
sample_names_plate1 <- c("454", "991", "991 + 20% 1203", "991 + 20% 1223", NA)
sample_names_plate2 <- c("991 + 20% 1203 + 20% DF", "991 + 20% 1203 + 20% DP3F", "991 + 20% 1203 + 20% DP12F", "991 + 20% 1203 + 20% DP24F", "991 + 20% 1203 + 20% DP48F")
sample_names_plate3 <- c("991 + 20% 1223 + 20% DF", "991 + 20% 1223 + 20% DP3F", "991 + 20% 1223 + 20% DP12F", "991 + 20% 1223 + 20% DP24F", "991 + 20% 1223 + 20% DP48F")

# specify core shell shield (terms in the manuscript: core, lipid anchor, PEG-ligand)
core <- c("991", "454")
shell <- c("1203", "1223")
id_all <- c("core\npolyplex", "P12", "P12F", "P15F", "P24F", "P36F", "P60F", "HBG") # names on the x-axis 

#import raw data (96 well plate)
Plate1 <- as.tibble(read_excel("20181107 991 1203 1223 DP0-48F preincub Plate1.xlsx"))
Plate2 <- as.tibble(read_excel("20181107 991 1203 1223 DP0-48F preincub Plate2.xlsx"))
Plate3 <- as.tibble(read_excel("20181107 991 1203 1223 DP0-48F preincub Plate3.xlsx"))

# specify grid
cols <- c(1:12)
rows <- LETTERS[1:8]

# rename columns according to the 96 well plate layout
names(Plate1)[1:12] = str_c(cols, 1, sep = "_")
names(Plate2)[1:12] = str_c(cols, 2, sep = "_")
names(Plate3)[1:12] = str_c(cols, 3, sep = "_")

# choose only the measurement data from the file and add row names
Plate1 <- Plate1 %>%
  select("2_1":"11_1") %>%
  filter(!is.na(`5_1`) | !is.na(`11_1`)) %>%
  mutate_if(is.character, parse_double) %>%
  mutate("row" = rows) %>%
  mutate_if(is.numeric, funs(. /35 * 100)) # because only 35 µl out of 100 µl have been measured

Plate2 <- Plate2 %>%
  select("2_2":"11_2") %>%
  filter(!is.na(`5_2`) | !is.na(`11_2`)) %>%
  mutate_if(is.character, parse_double) %>%
  mutate("row" = rows) %>%
  mutate_if(is.numeric, funs(. /35 * 100))

Plate3 <- Plate3 %>%
  select("2_3":"11_3") %>%
  filter(!is.na(`5_3`) | !is.na(`11_3`)) %>%
  mutate_if(is.character, parse_double) %>%
  mutate("row" = rows) %>%
  mutate_if(is.numeric, funs(. /35 * 100))

#split data in siGFP, siCtrl and HBG data
#HBG
Plate1_HbG <- Plate1 %>%
  select(row, `2_1`:`6_1`) %>%
  filter(row == "B") %>%
  mutate(sample = "HBG1") %>%
  select(-row) %>%
  gather(`2_1`:`6_1`, key = "col", value = "RLU")

Plate2_HbG <- Plate2 %>%
  select(row, `2_2`:`6_2`) %>%
  filter(row == "B") %>%
  mutate(sample = "HBG2") %>%
  select(-row) %>%
  gather(`2_2`:`6_2`, key = "col", value = "RLU")  

Plate3_HbG <- Plate3 %>%
  select(row, `2_3`:`6_3`) %>%
  filter(row == "B") %>%
  mutate(sample = "HBG3") %>%
  select(-row) %>%
  gather(`2_3`:`6_3`, key = "col", value = "RLU")

# mean HBG
Plate1_HbG_mean <- Plate1_HbG %>%
  group_by(sample) %>%
  summarise(mean_RLU = mean(RLU))

Plate2_HbG_mean <- Plate2_HbG %>%
  group_by(sample) %>%
  summarise(mean_RLU = mean(RLU))

Plate3_HbG_mean <- Plate3_HbG %>%
  group_by(sample) %>%
  summarise(mean_RLU = mean(RLU))

# add rel_RLU to HbG
Plate1_HbG <- Plate1_HbG %>%
  mutate(rel_RLU = RLU / Plate1_HbG_mean$mean_RLU)

Plate2_HbG <- Plate2_HbG %>%
  mutate(rel_RLU = RLU / Plate2_HbG_mean$mean_RLU)

Plate3_HbG <- Plate3_HbG %>%
  mutate(rel_RLU = RLU / Plate3_HbG_mean$mean_RLU)  

#siGFP
Plate1_GFP <- Plate1 %>%
  select(row, `2_1`:`6_1`) %>%
  filter(row %in% LETTERS[3:7]) %>%
  mutate(sample = sample_names_plate1) %>%
  select(-row) %>%
  gather(`2_1`:`6_1`, key = "col", value = "RLU") %>%
  mutate(rel_RLU = RLU / Plate1_HbG_mean$mean_RLU)

Plate2_GFP <- Plate2 %>%
  select(row, `2_2`:`6_2`) %>%
  filter(row %in% LETTERS[3:7]) %>%
  mutate(sample = sample_names_plate2) %>%
  select(-row) %>%
  gather(`2_2`:`6_2`, key = "col", value = "RLU")%>%
  mutate(rel_RLU = RLU / Plate2_HbG_mean$mean_RLU) 

Plate3_GFP <- Plate3 %>%
  select(row, `2_3`:`6_3`) %>%
  filter(row %in% LETTERS[3:7]) %>%
  mutate(sample = sample_names_plate3) %>%
  select(-row) %>%
  gather(`2_3`:`6_3`, key = "col", value = "RLU")%>%
  mutate(rel_RLU = RLU / Plate3_HbG_mean$mean_RLU)

#siCtrl
Plate1_Ctrl <- Plate1 %>%
  select(row, `7_1`:`11_1`) %>%
  filter(row %in% LETTERS[3:7]) %>%
  mutate(sample = sample_names_plate1) %>%
  select(-row) %>%
  gather(`7_1`:`11_1`, key = "col", value = "RLU")%>%
  mutate(rel_RLU = RLU / Plate1_HbG_mean$mean_RLU) 

Plate2_Ctrl <- Plate2 %>%
  select(row, `7_2`:`11_2`) %>%
  filter(row %in% LETTERS[3:7]) %>%
  mutate(sample = sample_names_plate2) %>%
  select(-row) %>%
  gather(`7_2`:`11_2`, key = "col", value = "RLU")%>%
  mutate(rel_RLU = RLU / Plate2_HbG_mean$mean_RLU) 

Plate3_Ctrl <- Plate3 %>%
  select(row, `7_3`:`11_3`) %>%
  filter(row %in% LETTERS[3:7]) %>%
  mutate(sample = sample_names_plate3) %>%
  select(-row) %>%
  gather(`7_3`:`11_3`, key = "col", value = "RLU")%>%
  mutate(rel_RLU = RLU / Plate3_HbG_mean$mean_RLU) 

# combination of HBG, GFP and Ctrl samples
GFP <- rbind(Plate1_GFP, Plate2_GFP, Plate3_GFP) %>%
  filter(!is.na(sample)) %>%
  mutate ( group = "GFP")

Ctrl <- rbind(Plate1_Ctrl, Plate2_Ctrl, Plate3_Ctrl) %>%
  filter(!is.na(sample)) %>%
  mutate ( group = "Ctrl")

HBG <- rbind(Plate1_HbG, Plate2_HbG, Plate3_HbG) %>%
  filter(!is.na(sample)) %>%
  mutate ( group = "HbG")
# add new row "id" for adequately naming samples on the x-axis
LucAssay <- rbind(GFP, Ctrl, HBG) %>%
  mutate(core = str_extract(sample, str_c("(", str_c(core, collapse = ")|(") , ")")))%>%     # adds a new column according to string specified in variable "core"
  mutate(shell = str_extract(sample, str_c("(", str_c(shell, collapse = ")|(") , ")")))%>%   # adds a new column that specifies id of the used shell according to string specified in variable "shell"
  mutate(shield = str_extract(sample, "D.*F")) %>%  # adds a new column that specifies names of the used shield with regex that starts with D and stops with F
  mutate(id = ifelse(is.na(shield) & is.na(shell), id_all[1], id_all[2])) %>%
  mutate(shield = ifelse(is.na(shield), 0, shield)) %>% # replace NAs with 0 to inclued it in ANOAVA
  mutate(id = ifelse(shield == "DF", id_all[3], id)) %>%
  mutate(id = ifelse(shield == "DP3F", id_all[4], id)) %>%
  mutate(id = ifelse(shield == "DP12F", id_all[5], id)) %>%
  mutate(id = ifelse(shield == "DP24F", id_all[6], id)) %>%
  mutate(id = ifelse(shield == "DP48F", id_all[7], id)) %>%
  mutate(id = ifelse(group == "HbG", "HBG", id)) %>%
  mutate(id = factor(id, levels = id_all))

# split "LucAssay" in GFP and control tibbles
LucAssay_GFP <- filter(LucAssay, group == "GFP" & (shell==1203 | shell == 1223)) 

LucAssay_Ctrl <- filter(LucAssay, group == "Ctrl") 


# stats - take care to finish restructuring the data, since the following packages interfere with the code above
#ttest: welch's ttest used (method: ttset: (welch test))
library(car) # Levene's Test
library(pastecs) # stat.desc
library(sjstats) # anova_stats
library(effsize) # cohen.d

#descriptive stats
by(LucAssay_GFP$RLU, LucAssay_GFP$shell, stat.desc) 
by(LucAssay_GFP$RLU, LucAssay_GFP$shield, stat.desc) 
by(LucAssay_GFP$RLU, list(LucAssay_GFP$shell, LucAssay_GFP$shield), stat.desc) # combination effect

#Levene's test
leveneTest(LucAssay_GFP$rel_RLU , LucAssay_GFP$shell, center = median) 
leveneTest(LucAssay_GFP$rel_RLU, LucAssay_GFP$shield, center = median)
leveneTest(LucAssay_GFP$rel_RLU, interaction(LucAssay_GFP$shell, LucAssay_GFP$shield), center = median)

#factorial ANOVA
LucAssay_RLU_Model<-aov(rel_RLU ~ shell*shield, data = LucAssay_GFP)
anova_GFP <- Anova(LucAssay_RLU_Model, type="III") # type: Displays type 1, 2 oder 3 sums of squares

anova_GFP$`Pr(>F)` # access anova results (stored as matrix)

anova_stats(LucAssay_RLU_Model) # displays stats associated with ANOVA (df sumsq meansq statistic p.value etasq partial.etasq omegasq partial.omegasq cohens.f power)

# prepare data for post hoc tests
LucAssay_GFP_1203 <- filter(LucAssay_GFP, shell == "1203")
LucAssay_GFP_1223 <- filter(LucAssay_GFP, shell == "1223")

# Post Hoc Analysis (CAVE: when interactions are significant, post hoc tests on the main result are missleading)
ttest_1203 <- pairwise.t.test(LucAssay_GFP_1203$rel_RLU, LucAssay_GFP_1203$shield, p.adjust.method = "none")  #bonferroni oder holm correction 
#ttest_1203$p.value[1,1] # access p values by their position in a matrix

ttest_1223 <- pairwise.t.test(LucAssay_GFP_1223$rel_RLU, LucAssay_GFP_1223$shield, p.adjust.method = "none")

#t-test: different shell (lipid anchor), same shield (PEG-ligand), subsequently calculated -> afterwards, correct with p.adjust().
LucAssay_GFP_0 <-filter(LucAssay_GFP, shield == "0")
ttest_GFP_0 <- pairwise.t.test(LucAssay_GFP_0$rel_RLU, LucAssay_GFP_0$shell, p.adjust.method = "none")

LucAssay_GFP_DF <-filter(LucAssay_GFP, shield == "DF")
ttest_GFP_DF <- pairwise.t.test(LucAssay_GFP_DF$rel_RLU, LucAssay_GFP_DF$shell, p.adjust.method = "none")

LucAssay_GFP_DP3F <-filter(LucAssay_GFP, shield == "DP3F")
ttest_GFP_DP3F <- pairwise.t.test(LucAssay_GFP_DP3F$rel_RLU, LucAssay_GFP_DP3F$shell, p.adjust.method = "none")

LucAssay_GFP_DP12F <-filter(LucAssay_GFP, shield == "DP12F")
ttest_GFP_DP12F <- pairwise.t.test(LucAssay_GFP_DP12F$rel_RLU, LucAssay_GFP_DP12F$shell, p.adjust.method = "none")

LucAssay_GFP_DP24F <-filter(LucAssay_GFP, shield == "DP24F")
ttest_GFP_DP24F <- pairwise.t.test(LucAssay_GFP_DP24F$rel_RLU, LucAssay_GFP_DP24F$shell, p.adjust.method = "none")

LucAssay_GFP_DP48F <-filter(LucAssay_GFP, shield == "DP48F")
ttest_GFP_DP48F <- pairwise.t.test(LucAssay_GFP_DP48F$rel_RLU, LucAssay_GFP_DP48F$shell, p.adjust.method = "holm")

# turn values into levels
levels <- levels(as.factor(LucAssay_GFP$shield))

# correction of p values
ttest_1203_1223 <- c(ttest_GFP_0$p.value[1,1], 
                     ttest_GFP_DF$p.value[1,1],  
                     ttest_GFP_DP12F$p.value[1,1], 
                     ttest_GFP_DP24F$p.value[1,1], 
                     ttest_GFP_DP3F$p.value[1,1], 
                     ttest_GFP_DP48F$p.value[1,1]
                     )
ttest_1203_1223 <- cbind(ttest_1203_1223, levels)

cols_1203 <- c(1:5)
rows_1203 <- rep(1, 5)
call_1203 <- cbind(cols_1203, rows_1203)
  # comparisom 991 + 1203 (without shell (lipid anchor)) = base
ttest_1203_shields <- cbind(
  p.value = ttest_1203$p.value[call_1203], 
  name = str_c(rownames(ttest_1203$p.value), "1203", sep ="_")
  )
 # comparisom 991 + 1223 (without shell (lipid anchor)) = base
ttest_1223_shields <- cbind(
  p.value = ttest_1223$p.value[call_1203], 
  name = str_c(rownames(ttest_1223$p.value), "1223", sep ="_")
  )
  # correction
p_unadjusted <- as.tibble(rbind(ttest_1203_1223, ttest_1203_shields, ttest_1223_shields))
p_unadjusted$ttest_1203_1223 <- parse_double(p_unadjusted$ttest_1203_1223)
p_adjusted <-p_unadjusted %>%
  rename(p.unadjusted = ttest_1203_1223) %>%
  mutate(p.adjusted = p.adjust( p_unadjusted$ttest_1203_1223, method = "holm")) %>%
  arrange (-desc(p.unadjusted))

p_adjusted_sig <- p_adjusted %>% # only values with p.adj. <= 0.05
  filter(p.adjusted <= 0.05)

round(p_adjusted$p.adjusted, 3)

# calculate cohen's d
# GFP
#specify control values, select rel_RLU only.
control_GFP_1203 <- LucAssay_GFP %>% 
  filter(sample == "991 + 20% 1203") %>%
  dplyr::select(rel_RLU)

control_GFP_1223 <- LucAssay_GFP %>% 
  filter(sample == "991 + 20% 1223") %>%
  dplyr::select(rel_RLU)

# convert name to factor to be able to use levels for selecting target values
LucAssay_GFP_1203 <- LucAssay_GFP %>%
  filter(shell == "1203") %>%
  mutate(sample = factor(sample))

LucAssay_GFP_1223 <- LucAssay_GFP %>%
  filter(shell == "1223") %>%
  mutate(sample = factor(sample))
  
#creat a vector for adding results
cohens_GFP_1203 <- c() 
cohens_GFP_1223 <- c()

#iterate over all levels of the factor, calculate respective cohen's d and write to vector
#1203 vs 1203-PEG-ligand
for (i in levels(LucAssay_GFP_1203$sample)) {
  a <- LucAssay_GFP_1203 %>%
    filter(sample == i) %>%
    dplyr::select(rel_RLU)
  b <- cohen.d(pull(a), pull(control_GFP_1203))
  cohens_GFP_1203 <- c(cohens_GFP_1203, b$estimate)
}

#1223 vs 1223-PEG-ligand
for (i in levels(LucAssay_GFP_1223$sample)) {
  a <- LucAssay_GFP_1223 %>%
    filter(sample == i) %>%
    dplyr::select(rel_RLU)
  b <- cohen.d(pull(a), pull(control_GFP_1223))
  cohens_GFP_1223 <- c(cohens_GFP_1223, b$estimate)
}

#1203-ligand vs 1223-PEG-ligand
cohens_GFP_1203_1223 <- c()

for (i in 1:length(levels(LucAssay_GFP_1223$sample))) {
  a <- levels(LucAssay_GFP_1203$sample)[i]
  b <- levels(LucAssay_GFP_1223$sample)[i]
  c <- LucAssay_GFP_1203 %>%
    filter(sample == a) %>%
    dplyr::select(rel_RLU)
  d <- LucAssay_GFP_1223 %>%
    filter(sample == b) %>%
    dplyr::select(rel_RLU)
  e <- cohen.d(pull(c), pull(d))
  cohens_GFP_1203_1223 <- c(cohens_GFP_1203_1223, e$estimate)
}
#combine: add cohen's d to tibble with t values
#1203 vs 1203-ligand
cohens_GFP_1203_cd <- as.tibble(cbind( "name" = levels(LucAssay_GFP_1203$sample),"cohens_d" = cohens_GFP_1203)) %>%
  mutate(cohens_d = as.double(cohens_d))

#1223 vs 1223-ligand
cohens_GFP_1223_cd <- as.tibble(cbind( "name" = levels(LucAssay_GFP_1223$sample),"cohens_d" = cohens_GFP_1223)) %>%
  mutate(cohens_d = as.double(cohens_d))

#1203-ligand vs 1223-ligand
cohens_GFP_1203_1223_cd <- as.tibble(cbind( "name_1203" = levels(LucAssay_GFP_1203$sample), "name_1223" = levels(LucAssay_GFP_1223$sample),"cohens_d" = cohens_GFP_1203_1223)) %>%
  mutate(cohens_d = as.double(cohens_d))
#end statistic calculations
#------------------------------------------------------------------------------------

# transformations for plotting
# remove HbG
LucAssay_plot <- LucAssay %>%
  filter(group != "HbG") 

# change order of sample names for printing the plot correctly  
LucAssay_plot$sample<-factor(LucAssay_plot$sample, levels = c(sample_names_plate1[!is.na(sample_names_plate1)], sample_names_plate2, sample_names_plate3))

#create subsets for subsequent plots
LucAssay_plot_991 <- LucAssay_plot%>%
  filter(is.na(shell) & core == "991")

LucAssay_plot_1203 <- LucAssay_plot%>%
  filter(shell =="1203")
  
LucAssay_plot_1223 <- LucAssay_plot%>%
  filter(shell =="1223")

LucAssay_plot_1203_1223 <- LucAssay_plot%>%
  filter(!is.na(shell) & group == "GFP")

#define colours for plots
colours <- brewer.pal(8, "Paired")
colours_core <- c(rep(colours[1], 5), rep(colours[2], 5))

# plotting
p5A <- ggplot(LucAssay_plot_1203, aes(id, rel_RLU, group = group, fill = group ) ) +
  stat_summary(fun.y = mean, geom = "bar", position = "dodge", width = 0.9, colour = "black") + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position=position_dodge(0.9) )+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  stat_summary(data = LucAssay_plot_991, aes(id, rel_RLU, group = group, fill = colours_core ), colour = "black", fun.y = mean, geom = "bar", position = "dodge", width = 0.9) + 
  geom_errorbar(data = LucAssay_plot_991, aes(id, rel_RLU, group = group ), stat = "summary", fun.data = mean_cl_normal, width=.2, position=position_dodge(0.9) ) +
  labs(
    x = NULL,
    y = "RLU [%] of HBG",
    title = "Luciferase activity assay",
    subtitle = "Core - LA - PEG-ligand polyplexes",
    colour = NULL,
    fill = NULL,
    tag = "A"
  ) +
  geom_signif(y_position=c(1.15, 1.25, 1.35, 1.45), xmin=c(2.2, 2.2, 2.2, 2.2), xmax=c(4.2, 5.2, 6.2, 7.2),
              annotation=c("***", "***", "***", "***"), tip_length=0) +
  theme_bw() +
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(0, 1.5)
    ) +
  scale_fill_manual("siRNA",
    values = c(colours[3], colours[4], colours[1], colours[2]),
    labels = c("Ctrl", "GFP", "Ctrl", "GFP")
  )

p5B <- ggplot(LucAssay_plot_1223, aes(id, rel_RLU, group = group, fill = group ) ) +
  stat_summary(fun.y = mean, geom = "bar", position = "dodge", width = 0.9, colour = "black") + 
  geom_errorbar(stat = "summary", fun.data = mean_cl_normal, width=.2, position=position_dodge(0.9) )+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  stat_summary(data = LucAssay_plot_991, aes(id, rel_RLU, group = group, fill = colours_core ), colour = "black", fun.y = mean, geom = "bar", position = "dodge", width = 0.9) + 
  geom_errorbar(data = LucAssay_plot_991, aes(id, rel_RLU, group = group ), stat = "summary", fun.data = mean_cl_normal, width=.2, position=position_dodge(0.9) ) +
  labs(
    x = "formulation",
    y = "RLU [%] of HBG",
    subtitle = "Core - LAE - PEG-ligand polyplexes",
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(0, 1.5)
  ) +
  geom_signif(
    y_position=c(1.2, 1.4), 
    xmin=c(2.2, 2.2), 
    xmax=c(5.2, 7.2),
    annotation=c("***", "***"), 
    tip_length=0
    ) +
  theme_bw() +
  scale_fill_manual("siRNA",
    values = c(colours[3], colours[4], colours[7], colours[8]),
    labels = c("Ctrl", "GFP", "Ctrl", "GFP")
    )
  
p5SI  <- ggplot(LucAssay_plot_1203_1223, aes(id, rel_RLU, group = shell, fill = shell ) ) +
  stat_summary(fun.y = mean, geom = "bar", position = "dodge", width = 0.9, colour = "black") + 
  geom_errorbar(stat = "summary", fun.data = mean_cl_normal, width=.2, position=position_dodge(0.9) )+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  labs(
    x = "formulation", 
    y = "RLU [%] of HBG",
    title = "Luciferase activity assay",
    subtitle = "Core - lipid anchor (LA, LAE) - PEG-ligand polyplexes",
    colour = NULL,
    fill = NULL
  ) +
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(0, 1.5)
  ) +
  theme_bw() +
  geom_signif(y_position=c(1.0, 1.0, 1.0), xmin=c(3.8, 4.8, 5.8), xmax=c(4.2, 5.2, 6.2),
              annotation=c("***","NS" , "***"), tip_length=0) +
  scale_fill_manual("lipid anchor",
                    values = c(colours[2], colours[8]), 
                    labels = c("LA", "LAE")
  )

# call multiplot to combine plots into one figure. copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}


ggsave("Figure5_Luc_AB.png", plot = multiplot(p5A, p5B,  cols=1),  width = 16, height = 18, units = c("cm"), dpi = 300)
ggsave("SIFigure5_Luc_C.png", plot = multiplot(p5SI,  cols=1),  width = 16, height = 9, units = c("cm"), dpi = 300)
