# This script imports DLS data from *.txt files exported by Malverns Zetasizer software.
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223
library(tidyverse)
library(splitstackshape)

setwd() # choose the folder where the raw data is stored

# specify core
core_all <- c("454", "1106")
ligand_all <- c("DF", "DP3F", "DP12F", "DP24F", "DP48F")

# specify id for plotting the data (sample names on x axis). Changing oder of items in vector changes order on x-axis
id_all <- c("HBG", "core\npolyplex", "F", "P3F", "P12F", "P24F", "P48F")

#import data
size <- as.tibble(read.delim("20181106_size.txt", header = TRUE, dec=",")) %>%
  filter (Type == "Size")
zeta <- as.tibble(read.delim("20181106_zeta.txt", header = TRUE, dec=",")) %>%
  filter (Type == "Zeta")

# tidy up data
size_tidy <- size %>%
  mutate(sample = ifelse(str_detect(Sample.Name, "\\+"), "core-ligand", "core")) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "25%"), 25, 0)) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "50%"), 50, `%`)) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "75%"), 75, `%`)) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "100%"), 100, `%`)) %>%
  mutate(id = id_all[3]) %>% # weird queue of commands due to inconsistent naming of Sample.Name (DFolA vs. DP0FolA)
  mutate(id = ifelse(str_detect(Sample.Name, "%"), id, id_all[2])) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[2]), id_all[4], id)) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[3]), id_all[5], id)) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[4]), id_all[6], id)) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[5]), id_all[7], id)) %>% 
  mutate(id = factor(id, levels = id_all[2:7])) # change order of factor levels
 
zeta_tidy <- zeta %>%
  mutate(sample = ifelse(str_detect(Sample.Name, "\\+"), "core-ligand", "core")) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "25%"), 25, 0)) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "50%"), 50, `%`)) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "75%"), 75, `%`)) %>%
  mutate("%" = ifelse(str_detect(Sample.Name, "100%"), 100, `%`)) %>%
  mutate(id = id_all[3]) %>% # weird queue of commands due to inconsistent naming of Sample.Name (DFolA vs. DP0FolA)
  mutate(id = ifelse(str_detect(Sample.Name, "%"), id, id_all[2])) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[2]), id_all[4], id)) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[3]), id_all[5], id)) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[4]), id_all[6], id)) %>%
  mutate(id = ifelse(str_detect(Sample.Name, ligand_all[5]), id_all[7], id))%>% 
  mutate(id = factor(id, levels = id_all[2:7])) # change order of factor levels

# select data for z average and pdi
zAv_data <- size_tidy %>%
  select(Type, Sample.Name, zAv = Z.Average..d.nm., PdI, id, `%`, sample )

#select data for zeta potential
zeta_data <- zeta_tidy %>%
  select(Sample.Name, zeta = Zeta.Potential..mV., zeta_dev = Zeta.Deviation..mV., id, `%`, sample ) %>%
  mutate(zeta_lower = zeta - zeta_dev) %>%
  mutate(zeta_upper = zeta + zeta_dev)

# summarize zeta_data for errorbars
zeta_data_errorbars <- zeta_data %>%
  group_by(`%`, id) %>%
  summarise(mean_zeta_lower = mean (zeta_lower), mean_zeta_upper = mean (zeta_upper))

# gather values for violin plot
size_violin <- size_tidy %>%
  select(-(Numbers.1...Percent.:Sizes.70...d.nm.))%>% # ausschluss von numbers und sizes columns
  gather(Intensities.1...Percent.:Intensities.70...Percent., key = "intensity_bins", value = "intensities")

# specify bins
bins <- size %>%
  select(Sample.Name, Sizes.1...d.nm.:Sizes.70...d.nm.)%>%
  gather(Sizes.1...d.nm.:Sizes.70...d.nm., key = "sizes", value = "bins")%>%
  filter(!is.na(bins))

size_violin$bins <- bins$bins

# choose violin data
violin_data <- size_violin %>%
  group_by(bins, id, `%`) %>%
  summarise(sum_intensities = sum(intensities)*10 )

# multiplikate each row by the value in "sum_intensities"
violin_data2 <- expandRows(violin_data, "sum_intensities") 

#define colours for plots
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey
colours_core <- c(rep(colours[6], 5), rep(colours[5], 5))

# plots
p6A <- ggplot (violin_data2, aes(x = id, y = bins)) +
  geom_violin() + 
  stat_summary(data = zAv_data, aes(y=zAv, fill = "z-average"), colour = "red", fun.y = mean, geom = "point") +
  geom_errorbar(data = zAv_data, aes(y=zAv), stat = "summary", fun.data =   mean_cl_normal, width=.2) +
  coord_trans(y='log10') + 
  scale_y_continuous (
    minor_breaks = c(c(1:9), seq(10, 90, 10), seq(100, 900, 100), seq(1000, 10000, 1000) ),
    limits = c(1, 10000), 
    breaks = c(1, 10, 100, 300, 1000, 10000)
  ) + 
  facet_grid(~ `%`, 
             scales = "free_x", 
             space = "free_x"
  ) +
  labs(
    x = NULL, 
    y = expression("d"[H]*" [nm]"),
    title = "DLS data of CON - PEG-ligand polyplexes",
    subtitle = expression("Hydrodynamic diameter d"[H]),
    colour = NULL,
    tag = "A"
  ) +
  theme_bw() +
  theme(
    legend.position = c(0.1, 0.97),
    legend.background = element_rect(size = 0.5, colour = "grey50"),
        legend.justification = c(0, 1),
        legend.title = element_blank(),
        axis.text.x=element_text(angle=45,hjust=1)
  ) 

p6B <- ggplot(zAv_data, aes(id, PdI)) +
  stat_summary (fun.y = mean, geom = "point", size = 3) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2) + # confidence interval from 3 consecutive measurements
  labs(
    x = NULL,
    y = "pdi",
    subtitle = "Polydispersity index (pdi)",
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  theme_bw(
  ) +
  facet_grid(~ `%`, 
             scales = "free_x", 
             space = "free_x"
  ) +
    scale_y_continuous (
    limits = c(0,1.05)
  ) + 
  theme(axis.text.x=element_text(angle=45,hjust=1))

p6C <- ggplot (zeta_data, aes(id, zeta)) +
  stat_summary (fun.y = mean, geom = "bar", size = 3) + 
  geom_errorbar(data=zeta_data_errorbars,  aes(y=NULL, x= id, ymin = mean_zeta_lower, ymax = mean_zeta_upper),   width=.2, position=position_dodge(0.9) )+
  labs(
    x = "formulation",
    y = "zeta potential [mV]",
    subtitle = "Zeta potential",
    colour = NULL,
    fill = NULL,
    tag = "C"
  ) +
  theme_bw(
  ) +
  facet_grid(~ `%`, 
             scales = "free_x", 
             space = "free_x"
  ) +
  theme(
    axis.text.x=element_text(angle=45,hjust=1)
    )

# plots are assembled in file "multiplot.R"

  

