# This script imports DLS data from *.txt files exported by Malverns Zetasizer software.
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223
library(tidyverse)
library(RColorBrewer)

# specify names
core_all <- c("991")
shell_all <- c("LA", "LAE")

# specify id for plotting the data (sample names on x axis). Changing oder of items in vector changes order on x-axis
id_all <- c("CO + siRNA\n+ lipid anchor", "CO + lipid anchor\n+ siRNA")

#import data
size <- as.tibble(read.delim("size.txt", header = TRUE, dec=",")) %>%
  filter (Type == "Size")
zeta <- as.tibble(read.delim("zeta.txt", header = TRUE, dec=",")) %>%
  filter (Type == "Zeta")

# tidy up data
size_tidy <- size %>%
  mutate(id = ifelse(str_detect(Sample.Name, "later"), id_all[2], id_all[1])) %>%
  mutate(shell = ifelse(str_detect(Sample.Name, "1203"), shell_all[1], shell_all[2])) %>%
  mutate(id = factor(id, levels = id_all)) %>% # change order of factor levels)
  mutate(shell = factor(shell, levels = shell_all))

zeta_tidy <- zeta %>%
  mutate(id = ifelse(str_detect(Sample.Name, "later"), id_all[2], id_all[1])) %>%
  mutate(shell = ifelse(str_detect(Sample.Name, "1203"), shell_all[1], shell_all[2])) %>%
  mutate(id = factor(id, levels = id_all)) %>% # change order of factor levels)
  mutate(shell = factor(shell, levels = shell_all))

# select data for z average and pdi
zAv_data <- size_tidy %>%
  select(Type, Sample.Name, zAv = Z.Average..d.nm., PdI, id, shell)

#select data for zeta potential
zeta_data <- zeta_tidy %>%
  select(Sample.Name, zeta = Zeta.Potential..mV., zeta_dev = Zeta.Deviation..mV., id, shell ) %>%
  mutate(zeta_lower = zeta - zeta_dev) %>%
  mutate(zeta_upper = zeta + zeta_dev)

# summarize zeta_data for errorbars
zeta_data_errorbars <- zeta_data %>%
  group_by(id, shell) %>%
  summarise(mean_zeta_lower = mean (zeta_lower), mean_zeta_upper = mean (zeta_upper))

#define colours for plots
colours <- brewer.pal(8, "Paired")
colours_core <- c(rep(colours[1], 5), rep(colours[2], 5))

# plots
SI_csh_A <- ggplot (zAv_data, aes(x = id, y = zAv, shape = shell)) +
  stat_summary(fun.y = mean, geom = "point",  aes(fill = shell), size = 3, position = position_dodge(width = 0.9)) +
  geom_errorbar( stat = "summary", fun.data =   mean_cl_normal, width=.2, position = position_dodge(width = 0.9)) +
  labs(
    x = NULL, 
    y = expression("d"[Z]*" [nm]"),
    title = "DLS data of CO - lipid anchor polyplexes ",
    subtitle = expression("Hydrodynamic diameter d"[Z]),
    colour = NULL,
    tag = "A"
  ) +
  theme_bw() + 
  scale_y_continuous (
    limits = c(0,500)
  )+
  scale_fill_manual(
    values = c(colours [2], colours[5]),
    name = "lipid anchor"
  ) +
  scale_shape_manual(
    values = c(21,22),
    name = "lipid anchor"
  )

SI_csh_B <- ggplot (zAv_data, aes(x = id, y = PdI, shape = shell)) +
  stat_summary(fun.y = mean, geom = "point",  aes(fill = shell), size = 3, position = position_dodge(width = 0.9)) +
  geom_errorbar( stat = "summary", fun.data =   mean_cl_normal, width=.2, position = position_dodge(width = 0.9)) +
  labs(
    x = NULL, 
    y = "PDI",
    title = NULL,
    subtitle = "Mean polydispersity index (PDI)",
    colour = NULL,
    tag = "B"
  ) +
  theme_bw() + 
  scale_y_continuous (
    limits = c(0,1)
  )+
  scale_fill_manual(
    values = c(colours [2], colours[5]),
    name = "lipid anchor"
  ) +
  scale_shape_manual(
    values = c(21,22),
    name = "lipid anchor"
  )

SI_csh_C <- ggplot (zeta_data, aes(x = id, y = zeta, shape = shell)) +
  stat_summary(fun.y = mean, geom = "point",  aes(fill = shell), size = 3, position = position_dodge(width = 0.9)) +
  geom_errorbar(data=zeta_data_errorbars,  aes(y=NULL, x= id, ymin = mean_zeta_lower, ymax = mean_zeta_upper),   width=.2, position=position_dodge(0.9) )+
  labs(
    x = "mixing order", 
    y = "zeta potential [mV]",
    title = NULL,
    subtitle = "Mean zeta potential",
    colour = NULL,
    tag = "C",
    caption ="assembly: pipettes"
  ) +
  theme_bw() + 
  scale_y_continuous (
    limits = c(0,25)
  )+
  scale_fill_manual(
    values = c(colours [2], colours[5]),
    name = "lipid anchor"
  ) +
  scale_shape_manual(
    values = c(21,22),
    name = "lipid anchor"
  )
# call multiplot to combine plots into one figure. Copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

ggsave("Supplemental_figure_S12_csh.png", plot = multiplot(SI_csh_A, SI_csh_B, SI_csh_C,  cols=1),  width = 16*0.75, height = 27*0.75, units = c("cm"), dpi = 300)

