# This script imports DLS data from *.txt files exported by Malverns Zetasizer software.
# The data is transformed into a tidy format and plotted with ggplot.

library(tidyverse)
library(splitstackshape)

# import data
size <- as.tibble(read.delim("stability_size.txt", header = TRUE, dec=",")) %>%
  filter (Type == "Size")
zeta <- as.tibble(read.delim("stability_zeta.txt", header = TRUE, dec=",")) %>%
  filter (Type == "Zeta")

# tidy up data
size_tidy <- size %>%
  mutate(date = str_extract(Measurement.Date.and.Time, "\\d\\d:\\d\\d:\\d\\d") ) %>%
  mutate(timepoint = str_extract(Sample.Name, "t=.*n")) %>%
  mutate(timepoint = str_extract(timepoint, "\\d+")) %>%
  mutate(timepoint = factor(timepoint, levels = sort(as.numeric(levels(factor(timepoint))))))

zeta_tidy <- zeta %>%
  mutate(date = str_extract(Measurement.Date.and.Time, "\\d\\d:\\d\\d:\\d\\d") ) %>%
  mutate(timepoint = str_extract(Sample.Name, "t=.*n")) %>%
  mutate(timepoint = str_extract(timepoint, "\\d+")) %>%
  mutate(timepoint = factor(timepoint, levels = sort(as.numeric(levels(factor(timepoint))))))

#select data for z average and pdi
zAv_data <- size_tidy %>%
  select(Type, Sample.Name, zAv = Z.Average..d.nm., PdI, timepoint )

#select data for zeta potential
zeta_data <- zeta_tidy %>%
  select(Sample.Name, zeta = Zeta.Potential..mV., zeta_dev = Zeta.Deviation..mV., timepoint ) %>%
  mutate(zeta_lower = zeta - zeta_dev) %>%
  mutate(zeta_upper = zeta + zeta_dev)

# summarize zeta_data for errorbars
zeta_data_errorbars <- zeta_data %>%
  group_by(timepoint) %>%
  summarise(mean_zeta_lower = mean (zeta_lower), mean_zeta_upper = mean (zeta_upper))

# gather values for violin plot
size_violin <- size_tidy %>%
  select(-(Numbers.1...Percent.:Sizes.70...d.nm.))%>% # ausschluss von numbers und sizes columns
  gather(Intensities.1...Percent.:Intensities.70...Percent., key = "intensity_bins", value = "intensities")

# specify bins
bins <- size %>%
  select(Sample.Name, Sizes.1...d.nm.:Sizes.70...d.nm.)%>%
  gather(Sizes.1...d.nm.:Sizes.70...d.nm., key = "sizes", value = "bins")%>%
  filter(!is.na(bins))

size_violin$bins <- bins$bins

# choose violin data
violin_data <- size_violin  %>%
  group_by(bins, timepoint) %>%
  summarise(sum_intensities = sum(intensities)*10 )

# multiplikate each row by the value in "sum_intensities"
violin_data2 <- expandRows(violin_data, "sum_intensities") 

# plots
pS13A <- ggplot (violin_data2, aes(x = timepoint, y = bins)) +
  geom_violin() + 
  stat_summary(data = zAv_data, aes(y=zAv, fill = "z-average"), colour = "red", fun.y = mean, geom = "point") +
  geom_errorbar(data = zAv_data, aes(y=zAv), stat = "summary", fun.data =   mean_cl_normal, width=.2) +
  coord_trans(y='log10') + 
  scale_y_continuous (
    minor_breaks = c(c(1:9), seq(10, 90, 10), seq(100, 900, 100), seq(1000, 10000, 1000) ),
    limits = c(1, 10000), 
    breaks = c(1, 10, 100, 300, 1000, 10000)
  ) +
  labs(
    x = NULL, 
    y = expression("d"[H]*" [nm]"),
    title = "DLS data of CO polyplexes over time",
    subtitle = expression("Hydrodynamic diameter d"[H]),
    colour = NULL,
    tag = "A"
  ) +
  theme_bw() +
  theme(
    legend.position = c(0.025, 0.95),
    legend.background = element_rect(size = 0.5, colour = "grey50"),
    legend.justification = c(0, 1),
    legend.title = element_blank()
  ) 

pS13B <- ggplot(zAv_data, aes(timepoint, PdI)) +
  stat_summary (fun.y = mean, geom = "point", size = 3) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2) + # confidence interval from 3 consecutive measurements
  labs(
    x = NULL,
    y = "PDI",
    subtitle = "Polydispersity index (PDI)",
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  theme_bw(
  ) +
  scale_y_continuous (
    limits = c(0,1.05)
  ) 

pS13C <- ggplot (zeta_data, aes(timepoint, zeta)) +
  stat_summary (fun.y = mean, geom = "bar", size = 3) + 
  geom_errorbar(data=zeta_data_errorbars,  aes(y=NULL, x= timepoint, ymin = mean_zeta_lower, ymax = mean_zeta_upper),   width=.2, position=position_dodge(0.9) )+
  labs(
    x = "time [min]",
    y = "zeta potential [mV]",
    subtitle = "Zeta potential",
    colour = NULL,
    fill = NULL,
    tag = "C",
    caption = "assembly: SMC"
  ) +
  theme_bw(
  )
# plots are assembled into the Figure S13 in the file "multiplot.R".
