# This script imports DLS data from *.txt files exported by Malverns Zetasizer software.
# The data is transformed into a tidy format and plotted with ggplot.
# Oligomers are named with their ids: CO: 991
library(tidyverse)

#import data
size_1 <- as.tibble(read.delim("size_tjunction.txt", header = TRUE, dec=","))%>%
  mutate(id = 1)
size_2 <- as.tibble(read.delim("size_tjunction_2.txt", header = TRUE, dec=","))%>%
  mutate(id = 2)
# combine imported data in one data frame
size <- rbind(size_1, size_2) 

# extract information from column "Sample.Name" and move it to separate columns
add_FR <- size %>%
  mutate(FR = str_extract(Sample.Name, "\\d+,?\\d?[ ]+ml/h"))
  
add_FR_2 <- add_FR %>%
  filter(is.na(FR))%>%
  mutate(FR = str_extract(Sample.Name, "\\d+k"))
  
add_FR_3 <-   add_FR_2 %>%
  filter(is.na(FR)) %>%
  filter(Sample.Name == str_extract(Sample.Name, "^9.*siRNA[ ]\\d$"))%>%
  mutate(FR = "hand")

comb_FR <- rbind (add_FR, add_FR_2, add_FR_3) %>%
  filter(!is.na(FR) )%>%
  filter(!is.na(PdI))

# add coding variables: flow rate (FR) und acetone concentration (acetone)
comb_FR <- comb_FR %>%
  mutate(FR = str_extract(FR, "(\\d,\\d|\\d+)|(\\D{3,})")) %>% 
  mutate(acetone = str_extract(Sample.Name, "(\\d,\\d|\\d+)[ ]?%")) %>%
  replace_na(list(acetone = "0%"))

comb_FR_subset <- comb_FR %>%
  filter(str_detect(comb_FR$Sample.Name, "tjunction")) %>%
  mutate(FR = as.double(str_extract(FR, "\\d+"))/2)

comb_FR <- comb_FR %>%
  filter(!str_detect(comb_FR$Sample.Name, "tjunction"))

DLS_ZAv <- rbind(comb_FR,comb_FR_subset)%>%
  select (Sample.Name,id, FR, acetone, Z.Average..d.nm., PdI, PdI.Width..d.nm., Attenuator)

#assign id's
Zav_0 <- DLS_ZAv %>%
  filter(FR == "hand") %>%
  mutate(id = 0)
Zav_1 <- DLS_ZAv %>%
  filter(id == 1)
 
Zav_2 <- DLS_ZAv %>%
  filter(id == 2, acetone == "0%", FR != "hand" )%>%
  mutate(FR = parse_double(FR, locale = locale(decimal_mark = ","))) # change FR from string to double
Zav_3 <- DLS_ZAv %>%
  filter(acetone == "2,5%") %>%
  mutate(id = 3) %>%
  mutate(FR = parse_double(FR, locale = locale(decimal_mark = ",")))  # change FR from string to double

Zav_4 <- DLS_ZAv %>% # 25% ac
  filter(acetone == "25%") %>%
  mutate(id = 4) %>%
  mutate(FR = parse_double(FR, locale = locale(decimal_mark = ","))) # change FR from string to double

DLS_Zav_tidy <- rbind (Zav_0, Zav_1, Zav_2, Zav_3, Zav_4) %>%
  mutate(FR_total = ifelse(FR == 0.5, "1", "hand")) %>%
  mutate(FR_total = ifelse(FR == 1, "2", FR_total)) %>%
  mutate(FR_total = ifelse(FR == 2.5, "5", FR_total)) %>%
  mutate(FR_total = ifelse(FR == 5, "10", FR_total)) %>%
  mutate(FR_total = ifelse(FR == 5, "10", FR_total)) %>%
  mutate(FR_total = ifelse(FR == 30, "60", FR_total)) 

# code id and FR as factors and change order of factor levels for accurate depiction in the plot
DLS_Zav_tidy$id <- as.factor(DLS_Zav_tidy$id)
DLS_Zav_tidy$FR_total <- as.factor(DLS_Zav_tidy$FR_total)
DLS_Zav_tidy$FR_total <- factor(DLS_Zav_tidy$FR_total, levels(DLS_Zav_tidy$FR_total)[c(6, 1, 3, 4, 2, 5)])

# change acetone to a number and change the column name to include "%"
DLS_Zav_tidy$acetone <- parse_number(DLS_Zav_tidy$acetone, locale = locale(decimal_mark = ","))
DLS_Zav_tidy <- rename(DLS_Zav_tidy, "acetone [%]"= acetone)

# choose fitting facetting strip names
levels(DLS_Zav_tidy$id) <- c("hand", "0 % acetone", "0 % acetone e1", "2.5 % acetone\nFR ratio 1/10", "25 % acetone")

#remove second experiment 0 % acetone
DLS_Zav_tidy <- DLS_Zav_tidy %>%
  filter(id != "0 % acetone e1")

Mean_ZAv_Data <- DLS_Zav_tidy %>%
  group_by(id, FR_total) %>%
  summarise(Zav_mean = mean(Z.Average..d.nm.))

#define colours for plots
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey. From colour brewer

#PDI Data
pdi_Data <- DLS_Zav_tidy %>%
  group_by(id, FR_total, `acetone [%]`) %>%
  summarise(
    pdi_mean = mean(PdI, na.rm = TRUE),
    pdi_sd = sd(PdI, na.rm = TRUE)
  ) %>%
  mutate(ymin = pdi_mean - pdi_sd) %>%
  mutate(ymax = pdi_mean + pdi_sd)

#plot data
p2A <-  ggplot(DLS_Zav_tidy, aes(FR_total, Z.Average..d.nm., colour = id)) +
  stat_summary(fun.y = mean, geom = "point", size = 3) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, colour = "black", alpha = 0.5) + # confidence interval from 3 consecutive measurements
  labs(
    x = NULL,
    y = expression("d"[Z]*" [nm]"),
    title = "DLS data of polyplex production at a T-junction",
    subtitle = expression("Hydrodynamic diameter d"[Z]),

    colour = NULL,
    fill = NULL,
    tag = "A"
  ) +
  theme_bw(
  ) +
  scale_y_continuous (
    limits = c(0,250)
  ) +
  theme(legend.position = "none") +
  facet_grid(~ id, 
             scales = "free_x", 
             space = "free_x"
  ) +
    scale_colour_manual(
    values = c(colours [5], colours[1], colours[3],colours[4] )
  )

p2B <-  ggplot(DLS_Zav_tidy, aes(FR_total, PdI, colour = id)) +
  stat_summary(fun.y = mean, geom = "point", size = 3) + 
  geom_errorbar(data = pdi_Data, aes(y=NULL, x= FR_total, ymin = ymin, ymax = ymax),   width=.2, colour = "black", alpha = .5 )+ # +- pdi standard deviation
  labs(
    x = "total flowrate [ml/h]",
    y = "PDI",
    subtitle = "Mean polydispersity index (PDI)",
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  theme_bw(
  ) +
  scale_y_continuous (
    limits = c(0,1)
  ) +
  theme(legend.position = "none") +
  facet_grid(~ id, 
             scales = "free_x", 
             space = "free_x"
  ) +
  scale_colour_manual(
    values = c(colours [5], colours[1], colours[3],colours[4])
  )

# call multiplot to combine plots into one figure. Copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

# save plots as .png
ggsave("Supplemental_figure_S14_tjunction.png", plot = multiplot(p2A, p2B, cols=1),  width = 16, height = 18, units = c("cm"), dpi = 300)
