# This script imports data from *.xlsx files exported by Tecan Reader (Tecan Trading AG, Switzerland, Spark 10M, SparkControl V 2.1).
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223
library(tidyverse)
library(readxl)
library(RColorBrewer)

#import raw data
Plate1 <- as.tibble(read_excel("20181109 MTT Assay 991 1203 1223 20mol% D1PEG0-48-FolA Plate1.xlsx", range = "A59:M67", col_names = FALSE)) 
Plate1_properties <- as.tibble(read_excel("20181109 MTT Assay 991 1203 1223 20mol% D1PEG0-48-FolA Plate1.xlsx", range = "A25:M26", col_names = FALSE)) %>%
  select("property" =`X__1`, "wavelenght [nm]" = `X__5` )
Plate2 <- as.tibble(read_excel("20181109 MTT Assay 991 1203 1223 20mol% D1PEG0-48-FolA Plate2.xlsx", range = "A59:M67", col_names = FALSE))
Plate2_properties <- as.tibble(read_excel("20181109 MTT Assay 991 1203 1223 20mol% D1PEG0-48-FolA Plate2.xlsx", range = "A25:M26", col_names = FALSE)) %>%
  select("property" =`X__1`, "wavelenght [nm]" = `X__5` )
Plate3 <- as.tibble(read_excel("20181109 MTT Assay 991 1203 1223 20mol% D1PEG0-48-FolA Plate3.xlsx", range = "A59:M67", col_names = FALSE))
Plate3_properties <- as.tibble(read_excel("20181109 MTT Assay 991 1203 1223 20mol% D1PEG0-48-FolA Plate3.xlsx", range = "A25:M26", col_names = FALSE)) %>%
  select("property" =`X__1`, "wavelenght [nm]" = `X__5` )

# define sample names
sample_names_plate1 <- c("454", "991", "991 + 20% 1203", "991 + 20% 1223", NA)
sample_names_plate2 <- c("991 + 20% 1203 + 20% DF", "991 + 20% 1203 + 20% DP3F", "991 + 20% 1203 + 20% DP12F", "991 + 20% 1203 + 20% DP24F", "991 + 20% 1203 + 20% DP48F")
sample_names_plate3 <- c("991 + 20% 1223 + 20% DF", "991 + 20% 1223 + 20% DP3F", "991 + 20% 1223 + 20% DP12F", "991 + 20% 1223 + 20% DP24F", "991 + 20% 1223 + 20% DP48F")

# specify core shell shield
core_all <- c("991", "454")
shell_all <- c("1203", "1223")

# specify id for plotting the data (sample names on x axis)
id_all <- c("HBG","none", "P12", "P12-F", "P12-3F", "P12-12F", "P12-24F", "P12-48F")

# tidy up the data
Plate1_tidy <- Plate1 %>% 
  filter(`X__1` %in% c("B", "C", "D", "E", "F")) %>%
  gather(`X__2`:`X__13`, key = "col", value = "fluorescence") %>%
  filter(!is.na(fluorescence)) %>%
  select ("row" = `X__1`, "col", "fluorescence" ) %>%
  mutate(fluorescence = as.double(fluorescence))  %>% 
  filter ( col != "X__2" , col != "X__13" ) %>%
  filter (row != "B" | col %in% c("X__3" ,"X__4", "X__5", "X__6", "X__7" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__8" ,"X__9", "X__10", "X__11", "X__12"), "ctrl", "GFP") ) %>%
  mutate (group = ifelse(row == "B", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "C",sample_names_plate1[1], "HBG1" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "D",sample_names_plate1[2], sample )) %>%
  mutate (sample = ifelse(row == "E",sample_names_plate1[3], sample )) %>%
  mutate (sample = ifelse(row == "F",sample_names_plate1[4], sample )) %>%
  mutate (shell = ifelse(row == "E", shell_all[1], "none")) %>% # add shell
  mutate (shell = ifelse(row == "F", shell_all[2], shell)) %>%
  mutate (id = ifelse(row == "C" |row == "D", id_all[2], id_all[1])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "E" |row == "F", id_all[3], id))

Plate2_tidy <- Plate2 %>% 
  filter(`X__1` %in% c("B", "C", "D", "E", "F", "G")) %>%
  gather(`X__2`:`X__13`, key = "col", value = "fluorescence") %>%
  filter(!is.na(fluorescence)) %>%
  select ("row" = `X__1`, "col", "fluorescence" )%>%
  mutate(fluorescence = as.double(fluorescence))%>% 
  filter ( col != "X__2" , col != "X__13" )%>%
  filter (row != "B" | col %in% c("X__3" ,"X__4", "X__5", "X__6", "X__7" )) %>%
  mutate (group = ifelse(col %in% c("X__8" ,"X__9", "X__10", "X__11", "X__12"), "ctrl", "GFP")) %>%
  mutate (group = ifelse(row == "B", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "C", sample_names_plate2[1], "HBG2" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "D", sample_names_plate2[2], sample )) %>%
  mutate (sample = ifelse(row == "E", sample_names_plate2[3], sample )) %>%
  mutate (sample = ifelse(row == "F", sample_names_plate2[4], sample )) %>%
  mutate (sample = ifelse(row == "G", sample_names_plate2[5], sample )) %>%
  mutate (shell = ifelse(row == "B", "none", shell_all[1])) %>% # add shell
  mutate (id = ifelse(row == "C", id_all[4], id_all[1])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "D", id_all[5], id)) %>%
  mutate (id = ifelse(row == "E", id_all[6], id)) %>%
  mutate (id = ifelse(row == "F", id_all[7], id)) %>%
  mutate (id = ifelse(row == "G", id_all[8], id))
 
Plate3_tidy <- Plate3 %>% 
  filter(`X__1` %in% c("B", "C", "D", "E", "F", "G")) %>%
  gather(`X__2`:`X__13`, key = "col", value = "fluorescence") %>%
  filter(!is.na(fluorescence)) %>%
  select ("row" = `X__1`, "col", "fluorescence" )%>%
  mutate(fluorescence = as.double(fluorescence))%>% 
  filter ( col != "X__2" , col != "X__13" )%>%
  filter (row != "B" | col %in% c("X__3" ,"X__4", "X__5", "X__6", "X__7" ))%>%
  mutate (group = ifelse(col %in% c("X__8" ,"X__9", "X__10", "X__11", "X__12"), "ctrl", "GFP") ) %>%
  mutate (group = ifelse(row == "B", "HBG", group )) %>%
  mutate (sample = ifelse(row == "C", sample_names_plate3[1], "HBG3" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "D", sample_names_plate3[2], sample )) %>%
  mutate (sample = ifelse(row == "E", sample_names_plate3[3], sample )) %>%
  mutate (sample = ifelse(row == "F", sample_names_plate3[4], sample )) %>%
  mutate (sample = ifelse(row == "G", sample_names_plate3[5], sample )) %>%
  mutate (shell = ifelse(row == "B", "none", shell_all[2])) %>% # add shell
  mutate (id = ifelse(row == "C", id_all[4], id_all[1])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "D", id_all[5], id)) %>%
  mutate (id = ifelse(row == "E", id_all[6], id)) %>%
  mutate (id = ifelse(row == "F", id_all[7], id)) %>%
  mutate (id = ifelse(row == "G", id_all[8], id))

# calculate mean fluorescence for all HBG groups to calculate relative fluorescence of target sample
mean_HBG1 <- Plate1_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluor = mean(fluorescence))

mean_HBG2 <- Plate2_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluor = mean(fluorescence))

mean_HBG3 <- Plate3_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_fluor = mean(fluorescence))

# calculate rel. fluorescence of all samples relative to their corresponding HBG values and combine data sets
Plate1_tidy_rel <- Plate1_tidy %>%
  mutate(rel_fluor = fluorescence / mean_HBG1$mean_fluor)

Plate2_tidy_rel <- Plate2_tidy %>%
  mutate(rel_fluor = fluorescence / mean_HBG2$mean_fluor)

Plate3_tidy_rel <- Plate3_tidy %>%
  mutate(rel_fluor = fluorescence / mean_HBG3$mean_fluor)

MTT_data <- rbind (Plate1_tidy_rel, Plate2_tidy_rel, Plate3_tidy_rel) %>%
  filter ( group != "HBG", sample != "454", sample != "991")

MTT_data_core <- rbind (Plate1_tidy_rel, Plate2_tidy_rel, Plate3_tidy_rel) %>%
  filter (sample == "991")

# change id to factor to order it sensibly  
MTT_data$id <- factor(MTT_data$id, levels = id_all[3:8])

#split the data sets in three sets: core, 1203 and 1223 
MTT_data_core <- rbind (Plate1_tidy_rel, Plate2_tidy_rel, Plate3_tidy_rel) %>%
  filter (sample == "991")

MTT_data_1203 <- MTT_data %>%
  filter(shell == "1203")

MTT_data_1223 <- MTT_data %>%
  filter(shell == "1223")

#define colours for plots
colours <- brewer.pal(8, "Paired")
colours_core <- c(rep(colours[1], 5), rep(colours[2], 5))

#plotting
SI_MTT_A <- ggplot(MTT_data_1203, aes(id, rel_fluor, group = group, fill = group ) ) + 
  stat_summary(fun.y = mean, geom = "bar", position = "dodge",colour = "black", width = 0.9) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position=position_dodge(0.9) )+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  stat_summary(data = MTT_data_core, aes(id, rel_fluor, group = group, fill = colours_core ),colour = "black", fun.y = mean, geom = "bar", position = "dodge", width = 0.9) + 
  geom_errorbar(data = MTT_data_core, aes(id, rel_fluor, group = group ), stat = "summary", fun.data = mean_cl_boot, width=.2, position=position_dodge(0.9) ) +
  labs(
    x = NULL, 
    y = "relative metabolic activity [%] of HBG",
    title = "MTT assay",
    subtitle = "Core - lipid anchor (LA) - PEG-ligand polyplexes",
    colour = NULL,
    fill = NULL,
    tag = "A"
  ) +
  theme_bw() +
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(0, 1.5)
  ) +
  scale_x_discrete(
    limits = c(id_all[2:8]) 
  ) +
  scale_fill_manual("siRNA",
                    values = c(colours[3], colours[4], colours[1], colours[2]),
                    labels = c("Ctrl", "GFP", "Ctrl", "GFP")
  )

SI_MTT_B <- ggplot(MTT_data_1223, aes(id, rel_fluor, group = group, fill = group ) ) + 
  stat_summary(fun.y = mean, geom = "bar", position = "dodge", width = 0.9, colour = "black") + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position=position_dodge(0.9) )+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  stat_summary(data = MTT_data_core, aes(id, rel_fluor, group = group, fill = colours_core ), colour = "black", fun.y = mean, geom = "bar", position = "dodge", width = 0.9) + 
  geom_errorbar(data = MTT_data_core, aes(id, rel_fluor, group = group ), stat = "summary", fun.data = mean_cl_boot, width=.2, position=position_dodge(0.9) ) +
  labs(
    x = NULL, 
    y = "relative metabolic activity [%] of HBG",
    subtitle = "Core - lipid anchor (LAE) - PEG-ligand polyplexes",
    colour = NULL,
    fill = NULL,
    tag = "B",
    caption = "assembly: DMC"
  ) +
  theme_bw() +
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(0, 1.5)
  ) +
  scale_x_discrete("lipid anchor - PEG-ligand",
    limits = c(id_all[2:8]) 
  ) +
  scale_fill_manual("siRNA",
                    values = c(colours[3], colours[4], colours[7], colours[8]),
                    labels = c("Ctrl", "GFP", "Ctrl", "GFP")
  )
# call multiplot to combine plots into one figure. copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

# save plots as .png
ggsave("Supplemental_figure_S21_MTT.png", plot = multiplot(SI_MTT_A, SI_MTT_B,  cols=1),  width = 16, height = 18, units = c("cm"), dpi = 300)
