# This script imports data from *.xlsx files exported by Centro LB 960 luminometer (BertholdTech CENTRO, Driver V. 1.21, MikroWin, V. 5.2).
# The data is transformed into a tidy format and plotted with ggplot.
# Oligomers are named with their ids: CON: 1106
library(tidyverse)
library(readxl)

# specify core
core_all <- c("1106")
ligand_all <- c("DF", "DP3F", "DP12F", "DP24F", "DP48F")

# specify id for plotting the data (sample names on x axis)
id_all <- c("HBG", "core\npolyplex", "F", "P3F", "P12F", "P24F", "P48F")

# define sample names
sample_names_plate1 <- c("1106")
sample_names_plate2 <- c("1106 + 75% DF", "1106 + 75% DP3F", "1106 + 75% DP12F", "1106 + 75% DP24F", "1106 + 75% DP48F")

#import raw data
Plate1 <- as.tibble(read_excel("20190627 1106 DP0-24F controls.xlsx",
                               range = "B29:K30",
                               col_names = FALSE)
) %>%
  mutate(row = LETTERS[1:2])

Plate2 <- as.tibble(read_excel("20190628 1106 DP0-24F 75% P1.xlsx",
                               range = "B29:K34",
                               col_names = FALSE)
) %>%
  mutate(row = LETTERS[1:6])

# tidy up the data
Plate1_tidy <- Plate1 %>%
  gather(`X__1`:`X__10`, key = "col", value = "RLU") %>% 
  filter (row != "A" | col %in% c("X__1" ,"X__2", "X__3", "X__4", "X__5" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__6" ,"X__7", "X__8", "X__9", "X__10"), "ctrl", "GFP") ) %>%
  mutate (group = ifelse(row == "A", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "B",sample_names_plate1[1], "HBG1" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (id = ifelse(row == "A" , id_all[1], id_all[2])) %>% #  add id for plotting nice graphs according to id
  mutate ("%" = 0)  

Plate2_tidy <- Plate2 %>% 
  gather(`X__1`:`X__10`, key = "col", value = "RLU") %>% 
  filter (row != "A" | col %in% c("X__1" ,"X__2", "X__3", "X__4", "X__5" ) ) %>% # removes colums without treatment
  mutate (group = ifelse(col %in% c("X__6" ,"X__7", "X__8", "X__9", "X__10"), "ctrl", "GFP") ) %>% 
  mutate (group = ifelse(row == "A", "HBG", group) ) %>%
  mutate (sample = ifelse(row == "B",sample_names_plate2[1], "HBG3" )) %>% # add sample names to values according to names given in "define sample names" 
  mutate (sample = ifelse(row == "C",sample_names_plate2[2], sample )) %>%
  mutate (sample = ifelse(row == "D",sample_names_plate2[3], sample )) %>%
  mutate (sample = ifelse(row == "E",sample_names_plate2[4], sample )) %>%
  mutate (sample = ifelse(row == "F",sample_names_plate2[5], sample )) %>%
  mutate (id = ifelse(row == "A", id_all[1], id_all[3])) %>% #  add id for plotting nice graphs accoding to id 
  mutate (id = ifelse(row == "C" , id_all[4], id)) %>%
  mutate (id = ifelse(row == "D" , id_all[5], id)) %>%
  mutate (id = ifelse(row == "E" , id_all[6], id)) %>%
  mutate (id = ifelse(row == "F" , id_all[7], id)) %>%
  mutate ("%" = ifelse (group == "HBG", 0, 75))


# calculate mean RLU for all HBG groups to calculate relative RLU of target sample
mean_HBG1 <- Plate1_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_RLU = mean(RLU))

mean_HBG2 <- Plate2_tidy %>%
  filter(group == "HBG") %>%
  summarise(mean_RLU = mean(RLU))

# calculate rel. RLU of all samples relative to their corresponding HBG values and combine data sets
Plate1_tidy_rel <- Plate1_tidy %>%
  mutate(rel_RLU = RLU / mean_HBG1$mean_RLU)

Plate2_tidy_rel <- Plate2_tidy %>%
  mutate(rel_RLU = RLU / mean_HBG2$mean_RLU)


#combine tibbles
Luc_tidy <- rbind(Plate1_tidy_rel, Plate2_tidy_rel) %>%
  filter(id != "HBG") 

# change id to fator and reorder levels
Luc_tidy$id <- factor(Luc_tidy$id, levels = id_all)

#define colours for plots
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey
colours_core <- c(rep(colours[6], 5), rep(colours[5], 5))

#plots
pSI24A <- ggplot(Luc_tidy, aes(id, rel_RLU, group = group, fill = group ) ) +
  stat_summary(fun.y = mean, geom = "bar", position = "dodge", width = 0.9) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position=position_dodge(0.9))+ # position_dodge(x) muss der gleiche Wert sein wie im geom_bar(width= x), sonst sind die errorbars nicht in der Mitte.
  labs(
    x = NULL, 
    y = "RLU [%] of HbG",
    title = "CON - PEG-ligand polyplexes",
    subtitle = "Luciferase activity assay",
    colour = NULL,
    fill = NULL,
    tag = "A"
  ) +
  theme_bw() +
  facet_grid(~ `%`,
             scales = "free_x", 
             space = "free_x"
  ) + 
  scale_y_continuous(
    labels = scales::number_format(scale = 100),
    limits = c(0, 1.25)
  ) +
  # theme(axis.text.x=element_text(angle=45,hjust=1)) +
  scale_fill_manual("siRNA",
                    values = c(colours[6], colours[5]),
                    labels = c("Ctrl", "GFP")
  )

# plots are assembled in file "multiplot.R"

#scatterplots to inspect the raw data
ggplot(Plate1_tidy, aes(id, RLU, group = group, colour = group ) ) + 
  geom_jitter(width = 0.15) +
  theme_bw()+ 
  coord_trans(y='log10')  
