# This script imports DLS data from *.txt files exported by Malverns Zetasizer software.
# The data is transformed into a tidy format and plotted with ggplot.
# lipid anchors are termed "shell" here. Oligomers are named with their ids: CO: 991, LA: 1203, LAE: 1223
library(tidyverse)

setwd() # choose the folder where the raw data is stored

#import data
size_csa_4inlet <- as.tibble(read.delim("size_core+shell_4inlet_2meander_20190129.txt", header = TRUE, dec=",")) # everything mixed in one channel: c1: 991, c2: siRNA, -meander- c3, c4: shell (1203 or 1223) -meander-

#define ids
id_all <- c("core", "core - LA", "core - LAE", "core - LA -\nP36F", "core - LAE -\nP24F" )

#tidy up the data
size_csa_4inlet_tidy <- size_csa_4inlet %>%
  filter(!is.na(PdI)) %>%
  mutate(shell = if_else(str_detect(Sample.Name, "1223"), "SPE", "none")) %>%
  mutate(shell = if_else(str_detect(Sample.Name, "1203"), "SP", shell)) %>%
  mutate("mol%" = 20) %>%
  mutate("NP" = 12) %>%
  mutate( id = "csa_4inlet") %>%
  mutate(acetone = if_else(str_detect(Sample.Name, "Ac"), "+", "-")) %>%
  mutate(ligand = if_else(str_detect(Sample.Name, "DP12F"), "DP12F", "none")) %>%
  mutate(ligand = if_else(str_detect(Sample.Name, "DP24F"), "DP24F", ligand)) %>%
  mutate(formulation = if_else(str_detect(shell, "none"), id_all[1], id_all[2])) %>%
  mutate(formulation = if_else(str_detect(shell, "SPE"), id_all[3], formulation)) %>%
  mutate(formulation = if_else(ligand == "DP12F", id_all[5], formulation)) %>%
  mutate(formulation = if_else(ligand == "DP24F", id_all[4], formulation)) %>%
  mutate(prod_method = if_else(str_detect(Sample.Name, "Micro"), "micro", "hand"))


DLS_4inlet <- size_csa_4inlet_tidy %>%
  select(Sample.Name,Z.Average..d.nm., PdI, formulation, shell, acetone, prod_method) %>%
  filter(prod_method == "micro") %>%
  filter(formulation != "core") %>%
  mutate(formulation = factor(formulation, levels = c(id_all[2], id_all[3], id_all[4], id_all[5])))

#define colours for plots
colours <- c("#3182bd", "#9ecae1", "#31a354", "#a1d99b", "#636363", "#bdbdbd") # blue, light blue, green, light green, grey, light grey. From colour brewer


pSI_size_4in <- ggplot(DLS_4inlet, aes(formulation, Z.Average..d.nm.,  shape = acetone)) +
  stat_summary(fun.y = mean, aes(fill = acetone), geom = "point", size = 3, position = position_dodge(width = 0.9)) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position = position_dodge(width = 0.9) ) + # confidence interval from 3 consecutive measurements
  labs(
    x = NULL,
    y =  expression("d"[H]*" [nm]"),
    title = "DLS data of controlled production of\ncore - lipid anchor - PEG-ligand polyplexes",
    subtitle = expression("Hydrodynamic diameter d"[H]),
    #caption = "Core - Shell - Shield polyplexes,
    colour = NULL,
    fill = NULL,
    tag = "A"
  ) +
  theme_bw(
  ) +
  scale_y_continuous (
    limits = c(0,200)
  )+
  scale_fill_manual(
    values = c(colours [5], colours[2]),
    name = "acetone"
  ) +
  scale_shape_manual(
    values = c(21,22),
    name = "acetone"
  )+
  theme(
    legend.position = c(0.5, 0.15),
    legend.direction = "horizontal", 
    legend.key = element_rect(color = "grey50"),
    legend.text = element_text(size = 15),
    legend.background = element_rect(size = 0.5, colour = "grey50")
  )

pSI_pdi_4in <- ggplot(DLS_4inlet, aes(formulation, PdI,  shape = acetone)) +
  stat_summary(aes(fill = acetone), fun.y = mean, geom = "point", size = 3, position = position_dodge(width = 0.9)) + 
  geom_errorbar(stat = "summary", fun.data =   mean_cl_normal, width=.2, position = position_dodge(width = 0.9) ) + # confidence interval from 3 consecutive measurements
  labs(
    x = "formulation",
    y = "pdi",
    #title = "Core production methods",
    subtitle = "Polydispersity index (pdi)",
    #caption = "Core - Shell - Shield polyplexes,
    colour = NULL,
    fill = NULL,
    tag = "B"
  ) +
  theme_bw(
  ) +
  scale_y_continuous (
    limits = c(0,1)
  )+
  scale_fill_manual(
    values = c(colours [5], colours[2]),
    name = "acetone"
  ) +
  scale_shape_manual(
    values = c(21,22),
    name = "acetone"
  ) + 
  theme(
    legend.position = "none"
  )

# call multiplot to combine plots into one figure. copied from http://www.cookbook-r.com/Graphs/Multiple_graphs_on_one_page_(ggplot2)/
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

ggsave("Supporting_figure_14_CSL_microfluidics.png", plot = multiplot(pSI_size_4in, pSI_pdi_4in, cols=1),  width = 16*0.75, height = 18, units = c("cm"), dpi = 300)
